@@ -10,7 +10,7 @@ def main():
         return
     
     values = tlog.get(path)
-    values.numpy.array(values).T
+    
     train_loss = values[0]
     train_acc = values[1]
     train_mean = values[2]
@@ -18,7 +18,7 @@ def main():
     valid_acc = values[4]
     valid_mean = values[5]
     
-    print(len(train_loss))
+    
     ax1 = plt.subplot(2, 1, 1)
     
     plt.plot(range(len(train_loss)),[round(float(v),2) for v in train_loss],'r')
@@ -30,10 +30,10 @@ def main():
     
     ax2 = plt.subplot(2, 1, 2)
     
-    ax2.plot(range(len(train_acc)),[round(float(v),2) for v in train_acc],'r')
+    #ax2.plot(range(len(train_acc)),[round(float(v),2) for v in train_acc],'r')
     ax2.plot(range(len(train_mean)),[round(float(v),2) for v in train_mean],'r--')
     
-    ax2.plot(range(len(valid_acc)),[round(float(v),2) for v in valid_acc],'b')
+    #ax2.plot(range(len(valid_acc)),[round(float(v),2) for v in valid_acc],'b')
     ax2.plot(range(len(valid_mean)),[round(float(v),2) for v in valid_mean],'b--')
     
     plt.title("acc")
