@@ -1,4 +1,5 @@
 import os
+import sys
 
 def getRoot(sec=[r"C:/"]):
     for r in sec:
@@ -8,6 +9,10 @@ def getRoot(sec=[r"C:/"]):
 app_path = r"{}FastCNN/Coach".format(getRoot([r"d:/","c:/"]))
 data_path = r"{}FastCNN/Data".format(getRoot([r"e:/",r"d:/","c:/"]))
 
+if sys.platform == "linux":
+    app_path = "/usr/local/app/Coach"
+    data_path = "usr/local/Data/"
+
 class PathProxy:
     """
     path define here
